#!/usr/bin/env python
import matplotlib
matplotlib.use('pgf')
import matplotlib.pyplot as plt
import pandas as pd


def calc_size(width_pt=360, fraction=1.0):
    fw_pt = width_pt * fraction
    inches_per_point = 1 / 72.0
    ratio = (5**0.5 - 1) / 2
    fw_in = fw_pt * inches_per_point
    fh_in = fw_in * ratio
    return (fw_in, fh_in)


if __name__ == '__main__':
    
    # get with an empty document and \showthe\textwidth
    #width, height = calc_size()
    #plt.figure(figsize=(width, height))
    plt.figure(figsize=calc_size())

    # read data
    df = pd.read_pickle('../443906_small.pkl.gz')

    # create histogram
    plt.hist(df.score, bins=20, fill=True, stacked=False, label=['Alle'])
    plt.yscale('log')
    plt.legend()
    plt.savefig('gen_score_all.pgf')
    plt.clf()

    # create table
    agg = pd.DataFrame(
        {
            'Gesamt': df.score.agg(['min', 'mean', 'max']).values,
            'Gäste': df.loc[(df.author.str.contains('(Gast)', regex=False)), :].score.agg(['min', 'mean', 'max']).values,
            'User': df.loc[(~df.author.str.contains('(Gast)', regex=False)), :].score.agg(['min', 'mean', 'max']).values
        },
        index=['Minimum', 'Durchschnitt', 'Maximum']
    )
    with open('gen_score_table.tex', 'w') as ofh: agg.style.to_latex(ofh)
